@@ -1,10 +1,10 @@
 package HTML::Tiny;
 
-use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.8';
+use vars qw/$VERSION/;
+$VERSION = '0.9';
 
 BEGIN {
 
@@ -50,14 +50,6 @@ my @UNPRINTABLE = qw(
   x18  x19  x1a  e    x1c  x1d  x1e  x1f
 );
 
-sub _hash_re {
-    my $hash = shift;
-    my $match = join( '|', map quotemeta, sort keys %$hash );
-    return qr/($match)/;
-}
-
-my $ENT_RE = _hash_re( \%ENT_MAP );
-
 sub new {
     my $class = shift;
     my $self = bless {}, $class;
@@ -77,7 +69,9 @@ sub _set_auto {
     my $value = shift;
 
     if ( defined $value ) {
-        $self->{autotag}->{$kind}->{$_} = $value for @_;
+        for ( @_ ) {
+            $self->{autotag}->{$kind}->{$_} = $value;
+        }
     }
     else {
         delete @{ $self->{autotag}->{$kind} }{@_};
@@ -152,7 +146,7 @@ sub query_encode {
 sub entity_encode {
     my $self = shift;
     my $str  = _str( shift );
-    $str =~ s/$ENT_RE/$ENT_MAP{$1}/eg;
+    $str =~ s/([<>&'"])/$ENT_MAP{$1}/eg;
     return $str;
 }
 
@@ -235,7 +229,7 @@ sub auto_tag {
     my ( $method, $pre, $post ) =
       map { $self->{autotag}->{$_}->{$name} || $DEFAULT_AUTO{$_} }
       ( 'method', 'prefix', 'suffix' );
-    my @out = map { "${pre}${_}${post}" } $self->$method( $name, @_ );
+    my @out = map { $pre . $_ . $post } $self->$method( $name, @_ );
     return wantarray ? @out : join '', @out;
 }
 
@@ -283,7 +277,7 @@ HTML::Tiny - Lightweight, dependency free HTML/XML generation
 
 =head1 VERSION
 
-This document describes HTML::Tiny version 0.8
+This document describes HTML::Tiny version 0.9
 
 =head1 SYNOPSIS
 
